#!/bin/bash
#
# Git Migration Checker is a little batch that detect when a new Rails migration is available after a git pull.
# If a migration have been found, it will proposed to execute this migration.
#
# http://www.zedroot.org/ - zedtux <zedtux@zedroot.org>
# Written on 2010-08-06
#
# Copyright (c) 2010, zedtux <zedtux@zedroot.org>
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the <organization> nor the
#       names of its contributors may be used to endorse or promote products
#       derived from this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL zedtux BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
#

SCRIPT_TAG="[Git Migration Checker]"

function count_migrations()
{
	echo `ls db/migrate/*.rb | wc -l | tr -d " "`
}

BEFORE_PULL=$(count_migrations)
echo "$SCRIPT_TAG Current project contain $BEFORE_PULL migrations"
echo "$SCRIPT_TAG Pulling git repository..."

git pull

AFTER_PULL=$(count_migrations)
if [ "$AFTER_PULL" != "$BEFORE_PULL" ]; then
	echo "$SCRIPT_TAG New migration found ! You should execute rake db:migrate and rake db:test:prepare !"
	echo "Do you want to execute new migration ? (y/N)"
	read ANSWER
	if [ "$ANSWER" = "y" ]; then
		rake db:migrate && rake db:test:prepare
	fi
else
	echo "$SCRIPT_TAG No migration detected."
fi

echo "$SCRIPT_TAG Good Bye =)"

exit